Documentation
¶
Overview ¶
Package template provides utility functions that help with the templating of created files.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AirTomlTemplate ¶
func AirTomlTemplate() []byte
func GitIgnoreTemplate ¶
func GitIgnoreTemplate() []byte
func MakeTemplate ¶
func MakeTemplate() []byte
MakeTemplate returns a byte slice that represents the default Makefile template.
func ReadmeTemplate ¶
func ReadmeTemplate() []byte
ReadmeTemplate returns a byte slice that represents the default README.md file template.
Types ¶
type GinTemplates ¶
type GinTemplates struct{}
GinTemplates contains the methods used for building an app that uses github.com/gin-gonic/gin
func (GinTemplates) Main ¶
func (g GinTemplates) Main() []byte
func (GinTemplates) Routes ¶
func (g GinTemplates) Routes() []byte
func (GinTemplates) Server ¶
func (g GinTemplates) Server() []byte
func (GinTemplates) TestHandler ¶
func (g GinTemplates) TestHandler() []byte
func (GinTemplates) WebsocketImports ¶
func (g GinTemplates) WebsocketImports() []byte
Click to show internal directories.
Click to hide internal directories.